Documentation
¶
Index ¶
- Variables
- type Aggregation
- func (Aggregation) Descriptor() protoreflect.EnumDescriptor
- func (x Aggregation) Enum() *Aggregation
- func (Aggregation) EnumDescriptor() ([]byte, []int)deprecated
- func (x Aggregation) Number() protoreflect.EnumNumber
- func (x Aggregation) String() string
- func (Aggregation) Type() protoreflect.EnumType
- type BasestationMessageType
- func (BasestationMessageType) Descriptor() protoreflect.EnumDescriptor
- func (x BasestationMessageType) Enum() *BasestationMessageType
- func (BasestationMessageType) EnumDescriptor() ([]byte, []int)deprecated
- func (x BasestationMessageType) Number() protoreflect.EnumNumber
- func (x BasestationMessageType) String() string
- func (BasestationMessageType) Type() protoreflect.EnumType
- type BssciVersion
- func (BssciVersion) Descriptor() protoreflect.EnumDescriptor
- func (x BssciVersion) Enum() *BssciVersion
- func (BssciVersion) EnumDescriptor() ([]byte, []int)deprecated
- func (x BssciVersion) Number() protoreflect.EnumNumber
- func (x BssciVersion) String() string
- func (BssciVersion) Type() protoreflect.EnumType
- type DeviceClass
- func (DeviceClass) Descriptor() protoreflect.EnumDescriptor
- func (x DeviceClass) Enum() *DeviceClass
- func (DeviceClass) EnumDescriptor() ([]byte, []int)deprecated
- func (x DeviceClass) Number() protoreflect.EnumNumber
- func (x DeviceClass) String() string
- func (DeviceClass) Type() protoreflect.EnumType
- type EndnodeMessageType
- func (EndnodeMessageType) Descriptor() protoreflect.EnumDescriptor
- func (x EndnodeMessageType) Enum() *EndnodeMessageType
- func (EndnodeMessageType) EnumDescriptor() ([]byte, []int)deprecated
- func (x EndnodeMessageType) Number() protoreflect.EnumNumber
- func (x EndnodeMessageType) String() string
- func (EndnodeMessageType) Type() protoreflect.EnumType
- type GeoLocation
- func (*GeoLocation) Descriptor() ([]byte, []int)deprecated
- func (x *GeoLocation) GetAlt() float64
- func (x *GeoLocation) GetLat() float64
- func (x *GeoLocation) GetLon() float64
- func (*GeoLocation) ProtoMessage()
- func (x *GeoLocation) ProtoReflect() protoreflect.Message
- func (x *GeoLocation) Reset()
- func (x *GeoLocation) String() string
- type MacPayloadFormat
- func (MacPayloadFormat) Descriptor() protoreflect.EnumDescriptor
- func (x MacPayloadFormat) Enum() *MacPayloadFormat
- func (MacPayloadFormat) EnumDescriptor() ([]byte, []int)deprecated
- func (x MacPayloadFormat) Number() protoreflect.EnumNumber
- func (x MacPayloadFormat) String() string
- func (MacPayloadFormat) Type() protoreflect.EnumType
- type Metric
- func (*Metric) Descriptor() ([]byte, []int)deprecated
- func (x *Metric) GetDatasets() []*MetricDataset
- func (x *Metric) GetKind() MetricKind
- func (x *Metric) GetName() string
- func (x *Metric) GetTimestamps() []*timestamppb.Timestamp
- func (*Metric) ProtoMessage()
- func (x *Metric) ProtoReflect() protoreflect.Message
- func (x *Metric) Reset()
- func (x *Metric) String() string
- type MetricDataset
- func (*MetricDataset) Descriptor() ([]byte, []int)deprecated
- func (x *MetricDataset) GetData() []float32
- func (x *MetricDataset) GetLabel() string
- func (*MetricDataset) ProtoMessage()
- func (x *MetricDataset) ProtoReflect() protoreflect.Message
- func (x *MetricDataset) Reset()
- func (x *MetricDataset) String() string
- type MetricKind
- type Region
- type VariableMacType
- func (VariableMacType) Descriptor() protoreflect.EnumDescriptor
- func (x VariableMacType) Enum() *VariableMacType
- func (VariableMacType) EnumDescriptor() ([]byte, []int)deprecated
- func (x VariableMacType) Number() protoreflect.EnumNumber
- func (x VariableMacType) String() string
- func (VariableMacType) Type() protoreflect.EnumType
Constants ¶
This section is empty.
Variables ¶
var ( Region_name = map[int32]string{ 0: "EU868", 2: "US915", 3: "CN779", 4: "EU433", 5: "AU915", 6: "CN470", 7: "AS923", 12: "AS923_2", 13: "AS923_3", 14: "AS923_4", 8: "KR920", 9: "IN865", 10: "RU864", } Region_value = map[string]int32{ "EU868": 0, "US915": 2, "CN779": 3, "EU433": 4, "AU915": 5, "CN470": 6, "AS923": 7, "AS923_2": 12, "AS923_3": 13, "AS923_4": 14, "KR920": 8, "IN865": 9, "RU864": 10, } )
Enum value maps for Region.
var ( EndnodeMessageType_name = map[int32]string{ 0: "ATTACHMENT", 1: "DETACHMENT", 2: "UNCONFIRMED_UL_DATA", 3: "CONFIRMED_UL_DATA", 4: "VARIABLE_MAC_UL_DATA", } EndnodeMessageType_value = map[string]int32{ "ATTACHMENT": 0, "DETACHMENT": 1, "UNCONFIRMED_UL_DATA": 2, "CONFIRMED_UL_DATA": 3, "VARIABLE_MAC_UL_DATA": 4, } )
Enum value maps for EndnodeMessageType.
var ( BasestationMessageType_name = map[int32]string{ 0: "CONNECT", 1: "STATUS", 2: "VARIABLE_MAC_STATUS", 3: "DOWNLINK_RESULT", 4: "DOWNLINK_RX_RESULT", } BasestationMessageType_value = map[string]int32{ "CONNECT": 0, "STATUS": 1, "VARIABLE_MAC_STATUS": 2, "DOWNLINK_RESULT": 3, "DOWNLINK_RX_RESULT": 4, } )
Enum value maps for BasestationMessageType.
var ( BssciVersion_name = map[int32]string{ 0: "BSSCI_1_0_0", } BssciVersion_value = map[string]int32{ "BSSCI_1_0_0": 0, } )
Enum value maps for BssciVersion.
var ( DeviceClass_name = map[int32]string{ 0: "CLASS_Z", 1: "CLASS_A", 2: "CLASS_B", 3: "CLASS_C", } DeviceClass_value = map[string]int32{ "CLASS_Z": 0, "CLASS_A": 1, "CLASS_B": 2, "CLASS_C": 3, } )
Enum value maps for DeviceClass.
var ( VariableMacType_name = map[int32]string{ 0: "WMBUS", 1: "MBUS_FFB", 2: "MBUS_MAC", 3: "MIOTY_ALLIANCE", 4: "CUSTOM", 5: "RESERVED", } VariableMacType_value = map[string]int32{ "WMBUS": 0, "MBUS_FFB": 1, "MBUS_MAC": 2, "MIOTY_ALLIANCE": 3, "CUSTOM": 4, "RESERVED": 5, } )
Enum value maps for VariableMacType.
var ( MacPayloadFormat_name = map[int32]string{ 0: "MBUS", 1: "MBUS_APL", 2: "IO_LINK", 3: "MBUS_MBAL", } MacPayloadFormat_value = map[string]int32{ "MBUS": 0, "MBUS_APL": 1, "IO_LINK": 2, "MBUS_MBAL": 3, } )
Enum value maps for MacPayloadFormat.
var ( Aggregation_name = map[int32]string{ 0: "HOUR", 1: "DAY", 2: "MONTH", 3: "MINUTE", } Aggregation_value = map[string]int32{ "HOUR": 0, "DAY": 1, "MONTH": 2, "MINUTE": 3, } )
Enum value maps for Aggregation.
var ( MetricKind_name = map[int32]string{ 0: "COUNTER", 1: "ABSOLUTE", 2: "GAUGE", } MetricKind_value = map[string]int32{ "COUNTER": 0, "ABSOLUTE": 1, "GAUGE": 2, } )
Enum value maps for MetricKind.
var File_common_common_proto protoreflect.FileDescriptor
var File_common_metrics_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type Aggregation ¶
type Aggregation int32
const ( // Hour. Aggregation_HOUR Aggregation = 0 // Day. Aggregation_DAY Aggregation = 1 // Month. Aggregation_MONTH Aggregation = 2 // Minute. Aggregation_MINUTE Aggregation = 3 )
func (Aggregation) Descriptor ¶
func (Aggregation) Descriptor() protoreflect.EnumDescriptor
func (Aggregation) Enum ¶
func (x Aggregation) Enum() *Aggregation
func (Aggregation) EnumDescriptor
deprecated
func (Aggregation) EnumDescriptor() ([]byte, []int)
Deprecated: Use Aggregation.Descriptor instead.
func (Aggregation) Number ¶
func (x Aggregation) Number() protoreflect.EnumNumber
func (Aggregation) String ¶
func (x Aggregation) String() string
func (Aggregation) Type ¶
func (Aggregation) Type() protoreflect.EnumType
type BasestationMessageType ¶
type BasestationMessageType int32
const ( // Basestation connection event. BasestationMessageType_CONNECT BasestationMessageType = 0 // Basestation status. BasestationMessageType_STATUS BasestationMessageType = 1 // Status of enabled variable mac types. BasestationMessageType_VARIABLE_MAC_STATUS BasestationMessageType = 2 // Downlink command result BasestationMessageType_DOWNLINK_RESULT BasestationMessageType = 3 // Result of a RX status query BasestationMessageType_DOWNLINK_RX_RESULT BasestationMessageType = 4 )
func (BasestationMessageType) Descriptor ¶
func (BasestationMessageType) Descriptor() protoreflect.EnumDescriptor
func (BasestationMessageType) Enum ¶
func (x BasestationMessageType) Enum() *BasestationMessageType
func (BasestationMessageType) EnumDescriptor
deprecated
func (BasestationMessageType) EnumDescriptor() ([]byte, []int)
Deprecated: Use BasestationMessageType.Descriptor instead.
func (BasestationMessageType) Number ¶
func (x BasestationMessageType) Number() protoreflect.EnumNumber
func (BasestationMessageType) String ¶
func (x BasestationMessageType) String() string
func (BasestationMessageType) Type ¶
func (BasestationMessageType) Type() protoreflect.EnumType
type BssciVersion ¶
type BssciVersion int32
const (
BssciVersion_BSSCI_1_0_0 BssciVersion = 0
)
func (BssciVersion) Descriptor ¶
func (BssciVersion) Descriptor() protoreflect.EnumDescriptor
func (BssciVersion) Enum ¶
func (x BssciVersion) Enum() *BssciVersion
func (BssciVersion) EnumDescriptor
deprecated
func (BssciVersion) EnumDescriptor() ([]byte, []int)
Deprecated: Use BssciVersion.Descriptor instead.
func (BssciVersion) Number ¶
func (x BssciVersion) Number() protoreflect.EnumNumber
func (BssciVersion) String ¶
func (x BssciVersion) String() string
func (BssciVersion) Type ¶
func (BssciVersion) Type() protoreflect.EnumType
type DeviceClass ¶
type DeviceClass int32
const ( // Class-Z. DeviceClass_CLASS_Z DeviceClass = 0 // Class-A. DeviceClass_CLASS_A DeviceClass = 1 // Class-B. DeviceClass_CLASS_B DeviceClass = 2 // Class-C. DeviceClass_CLASS_C DeviceClass = 3 )
func (DeviceClass) Descriptor ¶
func (DeviceClass) Descriptor() protoreflect.EnumDescriptor
func (DeviceClass) Enum ¶
func (x DeviceClass) Enum() *DeviceClass
func (DeviceClass) EnumDescriptor
deprecated
func (DeviceClass) EnumDescriptor() ([]byte, []int)
Deprecated: Use DeviceClass.Descriptor instead.
func (DeviceClass) Number ¶
func (x DeviceClass) Number() protoreflect.EnumNumber
func (DeviceClass) String ¶
func (x DeviceClass) String() string
func (DeviceClass) Type ¶
func (DeviceClass) Type() protoreflect.EnumType
type EndnodeMessageType ¶
type EndnodeMessageType int32
const ( // Over the air attachment. EndnodeMessageType_ATTACHMENT EndnodeMessageType = 0 // Over the air detachment. EndnodeMessageType_DETACHMENT EndnodeMessageType = 1 // Unconfirmed uplink. EndnodeMessageType_UNCONFIRMED_UL_DATA EndnodeMessageType = 2 // Confirmed uplink. EndnodeMessageType_CONFIRMED_UL_DATA EndnodeMessageType = 3 // Variable MAC uplink. EndnodeMessageType_VARIABLE_MAC_UL_DATA EndnodeMessageType = 4 )
func (EndnodeMessageType) Descriptor ¶
func (EndnodeMessageType) Descriptor() protoreflect.EnumDescriptor
func (EndnodeMessageType) Enum ¶
func (x EndnodeMessageType) Enum() *EndnodeMessageType
func (EndnodeMessageType) EnumDescriptor
deprecated
func (EndnodeMessageType) EnumDescriptor() ([]byte, []int)
Deprecated: Use EndnodeMessageType.Descriptor instead.
func (EndnodeMessageType) Number ¶
func (x EndnodeMessageType) Number() protoreflect.EnumNumber
func (EndnodeMessageType) String ¶
func (x EndnodeMessageType) String() string
func (EndnodeMessageType) Type ¶
func (EndnodeMessageType) Type() protoreflect.EnumType
type GeoLocation ¶
type GeoLocation struct {
Lat float64 `protobuf:"fixed64,1,opt,name=lat,proto3" json:"lat,omitempty"`
Lon float64 `protobuf:"fixed64,2,opt,name=lon,proto3" json:"lon,omitempty"`
Alt float64 `protobuf:"fixed64,3,opt,name=alt,proto3" json:"alt,omitempty"`
// contains filtered or unexported fields
}
func (*GeoLocation) Descriptor
deprecated
func (*GeoLocation) Descriptor() ([]byte, []int)
Deprecated: Use GeoLocation.ProtoReflect.Descriptor instead.
func (*GeoLocation) GetAlt ¶
func (x *GeoLocation) GetAlt() float64
func (*GeoLocation) GetLat ¶
func (x *GeoLocation) GetLat() float64
func (*GeoLocation) GetLon ¶
func (x *GeoLocation) GetLon() float64
func (*GeoLocation) ProtoMessage ¶
func (*GeoLocation) ProtoMessage()
func (*GeoLocation) ProtoReflect ¶
func (x *GeoLocation) ProtoReflect() protoreflect.Message
func (*GeoLocation) Reset ¶
func (x *GeoLocation) Reset()
func (*GeoLocation) String ¶
func (x *GeoLocation) String() string
type MacPayloadFormat ¶
type MacPayloadFormat int32
const ( // Indicates an M-Bus format as MAC payload format, starting with CI-field (see EN 13757-7) MacPayloadFormat_MBUS MacPayloadFormat = 0 // Indicates M-Bus APL data as MAC payload format, starting with a data information block (DIB) (see EN 13757-3) MacPayloadFormat_MBUS_APL MacPayloadFormat = 1 // Indicates an IO-Link application layer format as next layer MacPayloadFormat_IO_LINK MacPayloadFormat = 2 // Indicates an M-Bus format as next layer, using adaptation Layer, starting with MBAL (see EN 13757-8) MacPayloadFormat_MBUS_MBAL MacPayloadFormat = 3 )
func (MacPayloadFormat) Descriptor ¶
func (MacPayloadFormat) Descriptor() protoreflect.EnumDescriptor
func (MacPayloadFormat) Enum ¶
func (x MacPayloadFormat) Enum() *MacPayloadFormat
func (MacPayloadFormat) EnumDescriptor
deprecated
func (MacPayloadFormat) EnumDescriptor() ([]byte, []int)
Deprecated: Use MacPayloadFormat.Descriptor instead.
func (MacPayloadFormat) Number ¶
func (x MacPayloadFormat) Number() protoreflect.EnumNumber
func (MacPayloadFormat) String ¶
func (x MacPayloadFormat) String() string
func (MacPayloadFormat) Type ¶
func (MacPayloadFormat) Type() protoreflect.EnumType
type Metric ¶
type Metric struct {
// Name.
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// Timestamps.
Timestamps []*timestamppb.Timestamp `protobuf:"bytes,2,rep,name=timestamps,proto3" json:"timestamps,omitempty"`
// Datasets.
Datasets []*MetricDataset `protobuf:"bytes,3,rep,name=datasets,proto3" json:"datasets,omitempty"`
// Kind.
Kind MetricKind `protobuf:"varint,4,opt,name=kind,proto3,enum=common.MetricKind" json:"kind,omitempty"`
// contains filtered or unexported fields
}
func (*Metric) Descriptor
deprecated
func (*Metric) GetDatasets ¶
func (x *Metric) GetDatasets() []*MetricDataset
func (*Metric) GetKind ¶
func (x *Metric) GetKind() MetricKind
func (*Metric) GetTimestamps ¶
func (x *Metric) GetTimestamps() []*timestamppb.Timestamp
func (*Metric) ProtoMessage ¶
func (*Metric) ProtoMessage()
func (*Metric) ProtoReflect ¶
func (x *Metric) ProtoReflect() protoreflect.Message
type MetricDataset ¶
type MetricDataset struct {
// Label.
Label string `protobuf:"bytes,1,opt,name=label,proto3" json:"label,omitempty"`
// Data.
// Each value index corresponds with the same timestamp index of the Metric.
Data []float32 `protobuf:"fixed32,2,rep,packed,name=data,proto3" json:"data,omitempty"`
// contains filtered or unexported fields
}
func (*MetricDataset) Descriptor
deprecated
func (*MetricDataset) Descriptor() ([]byte, []int)
Deprecated: Use MetricDataset.ProtoReflect.Descriptor instead.
func (*MetricDataset) GetData ¶
func (x *MetricDataset) GetData() []float32
func (*MetricDataset) GetLabel ¶
func (x *MetricDataset) GetLabel() string
func (*MetricDataset) ProtoMessage ¶
func (*MetricDataset) ProtoMessage()
func (*MetricDataset) ProtoReflect ¶
func (x *MetricDataset) ProtoReflect() protoreflect.Message
func (*MetricDataset) Reset ¶
func (x *MetricDataset) Reset()
func (*MetricDataset) String ¶
func (x *MetricDataset) String() string
type MetricKind ¶
type MetricKind int32
const ( // Incrementing counters that never decrease (these are not reset on each // reading). MetricKind_COUNTER MetricKind = 0 // Counters that do get reset upon reading. MetricKind_ABSOLUTE MetricKind = 1 // E.g. a temperature value. MetricKind_GAUGE MetricKind = 2 )
func (MetricKind) Descriptor ¶
func (MetricKind) Descriptor() protoreflect.EnumDescriptor
func (MetricKind) Enum ¶
func (x MetricKind) Enum() *MetricKind
func (MetricKind) EnumDescriptor
deprecated
func (MetricKind) EnumDescriptor() ([]byte, []int)
Deprecated: Use MetricKind.Descriptor instead.
func (MetricKind) Number ¶
func (x MetricKind) Number() protoreflect.EnumNumber
func (MetricKind) String ¶
func (x MetricKind) String() string
func (MetricKind) Type ¶
func (MetricKind) Type() protoreflect.EnumType
type Region ¶
type Region int32
const ( // EU868 Region_EU868 Region = 0 // US915 Region_US915 Region = 2 // CN779 Region_CN779 Region = 3 // EU433 Region_EU433 Region = 4 // AU915 Region_AU915 Region = 5 // CN470 Region_CN470 Region = 6 // AS923 Region_AS923 Region = 7 // AS923 with -1.80 MHz frequency offset Region_AS923_2 Region = 12 // AS923 with -6.60 MHz frequency offset Region_AS923_3 Region = 13 // (AS923 with -5.90 MHz frequency offset). Region_AS923_4 Region = 14 // KR920 Region_KR920 Region = 8 // IN865 Region_IN865 Region = 9 // RU864 Region_RU864 Region = 10 )
func (Region) Descriptor ¶
func (Region) Descriptor() protoreflect.EnumDescriptor
func (Region) EnumDescriptor
deprecated
func (Region) Number ¶
func (x Region) Number() protoreflect.EnumNumber
func (Region) Type ¶
func (Region) Type() protoreflect.EnumType
type VariableMacType ¶
type VariableMacType int32
TODO - match storage format
const ( // MAC/LINK Layer optimized for metering applications (deprecated) VariableMacType_WMBUS VariableMacType = 0 // Wireless M-Bus frame with Frame Format B (FFB) VariableMacType_MBUS_FFB VariableMacType = 1 // M-Bus frame that starts with a wireless M-Bus MAC according to OMS-S Volume 2, Annex Q // // Open Metering System Specification (OMS-S), Volume 2, Annex Q, Issue 5.0.1, December 2023. VariableMacType_MBUS_MAC VariableMacType = 2 // / Mioty® Alliance MAC/LINK layers // / User specific MAC/LINK layer VariableMacType_MIOTY_ALLIANCE VariableMacType = 3 VariableMacType_CUSTOM VariableMacType = 4 VariableMacType_RESERVED VariableMacType = 5 )
func (VariableMacType) Descriptor ¶
func (VariableMacType) Descriptor() protoreflect.EnumDescriptor
func (VariableMacType) Enum ¶
func (x VariableMacType) Enum() *VariableMacType
func (VariableMacType) EnumDescriptor
deprecated
func (VariableMacType) EnumDescriptor() ([]byte, []int)
Deprecated: Use VariableMacType.Descriptor instead.
func (VariableMacType) Number ¶
func (x VariableMacType) Number() protoreflect.EnumNumber
func (VariableMacType) String ¶
func (x VariableMacType) String() string
func (VariableMacType) Type ¶
func (VariableMacType) Type() protoreflect.EnumType